@@ -21,50 +21,44 @@ const (
 )
 
 func expandToGitHubURL(ownerOrRepo string) string {
-	return fmt.Sprintf("^https://github.com/%s/", ownerOrRepo)
+	// TODO: handle proxima prefix
+	return fmt.Sprintf("(?i)^https://github.com/%s/", ownerOrRepo)
 }
 
 func buildSANMatcher(opts *Options) (verify.SubjectAlternativeNameMatcher, error) {
 	if opts.SignerRepo != "" {
 		signedRepoRegex := expandToGitHubURL(opts.SignerRepo)
-		return verify.NewSANMatcher("", "", signedRepoRegex)
+		return verify.NewSANMatcher("", signedRepoRegex)
 	} else if opts.SignerWorkflow != "" {
 		validatedWorkflowRegex, err := validateSignerWorkflow(opts)
 		if err != nil {
 			return verify.SubjectAlternativeNameMatcher{}, err
 		}
 
-		return verify.NewSANMatcher("", "", validatedWorkflowRegex)
+		return verify.NewSANMatcher("", validatedWorkflowRegex)
 	} else if opts.SAN != "" || opts.SANRegex != "" {
-		return verify.NewSANMatcher(opts.SAN, "", opts.SANRegex)
+		return verify.NewSANMatcher(opts.SAN, opts.SANRegex)
 	}
 
 	return verify.SubjectAlternativeNameMatcher{}, nil
 }
 
-func buildCertExtensions(opts *Options, runnerEnv string) certificate.Extensions {
-	extensions := certificate.Extensions{
-		Issuer:                   opts.OIDCIssuer,
-		SourceRepositoryOwnerURI: fmt.Sprintf("https://github.com/%s", opts.Owner),
-		RunnerEnvironment:        runnerEnv,
-	}
-
-	// if opts.Repo is set, set the SourceRepositoryURI field before returning the extensions
-	if opts.Repo != "" {
-		extensions.SourceRepositoryURI = fmt.Sprintf("https://github.com/%s", opts.Repo)
-	}
-	return extensions
-}
-
 func buildCertificateIdentityOption(opts *Options, runnerEnv string) (verify.PolicyOption, error) {
 	sanMatcher, err := buildSANMatcher(opts)
 	if err != nil {
 		return nil, err
 	}
 
-	extensions := buildCertExtensions(opts, runnerEnv)
+	issuerMatcher, err := verify.NewIssuerMatcher(opts.OIDCIssuer, "")
+	if err != nil {
+		return nil, err
+	}
 
-	certId, err := verify.NewCertificateIdentity(sanMatcher, extensions)
+	extensions := certificate.Extensions{
+		RunnerEnvironment: runnerEnv,
+	}
+
+	certId, err := verify.NewCertificateIdentity(sanMatcher, issuerMatcher, extensions)
 	if err != nil {
 		return nil, err
 	}
